#include <AccelStepper.h>

// X
const int dirPinX = 5;
const int stepPinX = 2;

// Y
const int dirPinY = 6;
const int stepPinY = 3;

// Z
const int dirPinZ = 7;
const int stepPinZ = 4;

// A
const int dirPinA = 13;
const int stepPinA = 12;

// Define some steppers and the pins the will use
AccelStepper stepperX(AccelStepper::DRIVER, stepPinX,dirPinX);
AccelStepper stepperY(AccelStepper::DRIVER, stepPinY, dirPinY);
AccelStepper stepperZ(AccelStepper::DRIVER, stepPinZ,dirPinZ);
AccelStepper stepperA(AccelStepper::DRIVER, stepPinA, dirPinA);

#define DISTANCE 200
#define MAX_SPEED 200.0
#define ACCEL 200

long positionStepperX = 0;
long positionStepperY = 0;
long positionStepperZ = 0;
long positionStepperA = 0;

void setup(){
  Serial.begin(9600);

  stepperX.setMaxSpeed(MAX_SPEED);
  stepperX.setAcceleration(ACCEL);
  stepperX.moveTo(positionStepperX);
  
  stepperY.setMaxSpeed(MAX_SPEED);
  stepperY.setAcceleration(ACCEL);
  stepperY.moveTo(positionStepperY);

  stepperZ.setMaxSpeed(MAX_SPEED);
  stepperZ.setAcceleration(ACCEL);
  stepperZ.moveTo(positionStepperZ);
  
  stepperA.setMaxSpeed(MAX_SPEED);
  stepperA.setAcceleration(ACCEL);
  stepperA.moveTo(positionStepperA);

}

void moveSteppers(){
  stepperX.moveTo(positionStepperX);
  stepperY.moveTo(positionStepperY);
  stepperZ.moveTo(positionStepperZ);
  stepperA.moveTo(positionStepperA);
}

char command; // used to read command from Serial connection

void loop(){

  if (Serial.available() > 0) {
    command = '0';

    // read byte
    command = Serial.read();

    // dir pin set to:
    //  - LOW rotates servo counter-clockwise
    //  - HIGH rotates servo clockwise
    
    Serial.print("Command: ");
    Serial.print(command);
    Serial.print("\n");

    switch(command){
      case 'l':
        //left
        positionStepperX+=DISTANCE;
        positionStepperY+=DISTANCE;
        positionStepperZ-=DISTANCE;
        positionStepperA-=DISTANCE;
        
        break;

      case 'f':
        //forward
        positionStepperX+=DISTANCE;
        positionStepperY-=DISTANCE;
        positionStepperZ-=DISTANCE;
        positionStepperA+=DISTANCE;

        break;

      case 'r':      
        //right
        positionStepperX-=DISTANCE;
        positionStepperY-=DISTANCE;
        positionStepperZ+=DISTANCE;
        positionStepperA+=DISTANCE;

        break;

      case 'b':
        //back
        positionStepperX-=DISTANCE;
        positionStepperY+=DISTANCE;
        positionStepperZ+=DISTANCE;
        positionStepperA-=DISTANCE;

        break;

      case 'u':
        //up
        positionStepperX+=DISTANCE;
        positionStepperY-=DISTANCE;
        positionStepperZ-=DISTANCE;
        positionStepperA-=DISTANCE;

        break;

      case 'd':
        //down
        positionStepperX-=DISTANCE;
        positionStepperY+=DISTANCE;
        positionStepperZ+=DISTANCE;
        positionStepperA-=DISTANCE;

        break;
    }

    moveSteppers();
  }

  if (stepperX.distanceToGo() != 0)
    stepperX.run();
  
  if (stepperY.distanceToGo() != 0)
    stepperY.run();

  if (stepperZ.distanceToGo() != 0)
    stepperZ.run();
  
  if (stepperA.distanceToGo() != 0)
    stepperA.run();

}